@@ -1,11 +1,11 @@
-# FIAIF is an Intelligent firewall, version: $Revision: 1.107 $
+# FIAIF is an Intelligent firewall
 #
 # description: Automates a packet filtering firewall with iptables.
 #
 # Script Author:	Anders Fugmann <afu at fugmann dot net>
 # 
 # FIAIF is an Intelligent firewall
-# Copyright (C) 2002-2004 Anders Peter Fugmann
+# Copyright (C) 2002-2011 Anders Peter Fugmann
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -423,9 +423,9 @@ function unload_modules ()
     local MODULE
     for MODULE in ${MODULES}; do
 	if (( TEST == 1 )); then
-	    echo "rmmod ${MODULE}" >> ${TEST_FILE}
+	    echo "modprobe -r ${MODULE}" >> ${TEST_FILE}
 	else
-	    rmmod ${MODULE} > /dev/null 2>&1
+	    modprobe -r ${MODULE} > /dev/null 2>&1
 	fi  
     done
 }
