@@ -1,11 +1,11 @@
-# FIAIF is an Intelligent firewall, version: $Revision: 1.140 $
+# FIAIF is an Intelligent firewall
 #
 # description: Automates a packet filtering firewall with iptables.
 #
-# Script Author:	Anders Fugmann <afu@fugmann.net>
+# Script Author:	Anders Fugmann <afu at fugmann dot net>
 # 
 # FIAIF is an Intelligent firewall
-# Copyright (C) 2002-2003 Anders Peter Fugmann
+# Copyright (C) 2002-2011 Anders Peter Fugmann
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -77,7 +77,7 @@ function read_zone ()
     declare -i DHCP_SERVER=${DHCP_SERVER:=0}
     declare -i DYNAMIC=${DYNAMIC:=1}
     declare -i TC_ENABLE=${TC_ENABLE:=0}
-    declare    TC_TYPE=${TC_TYPE:=CBQ}
+    declare    TC_TYPE=${TC_TYPE:=HTB}
 
     # Got all nessesary information about the interface?
     if (( DYNAMIC == 0 )); then	
@@ -516,6 +516,7 @@ function add_snat ()
 	local SNAT_IP
 	for SNAT_IP in ${SNAT_IPS}; do
 	    SNAT_PARAM="${SNAT_PARAM} --to-source ${SNAT_IP}"
+	    break
 	done
     else
 	NAT_TYPE="MASQUERADE"
